.. _release-0-4-4:

0.4.4
=====

Bokeh ``0.4.4`` (Apr 2014) is a minor release:

* Improved MPL interface, subplots, styling plus more examples
* TravisCI testing integration
* Tool enhancements, constrained pan/zoom, more hover glyphs
* Server remote data and downsampling examples
* Initial work for Bokeh "app" concept
